import argparse
import os
import re

LINE_RE = re.compile(r'^\s*(.*?)=(.*?)\s*$')

def parse_aws_credentials_file(fp):
    """Return a dictionary containing aws_access_key_id and aws_secret_access_key, given a file to a credentials file
       in the format expected by AWS tools (as described at http://j.mp/qGGHNp).
       
       This is a port of the Perl code in SES.pm, so should behave identically."""
    
    result = {}
    
    for line in fp:

        line = line.strip()
        match = LINE_RE.match(line)

        if not line:
            continue
        elif not match:
            raise ValueError, 'Cannot parse credentials file entry <%s>' % line
        elif match.group(1) == 'AWSAccessKeyId':
            result['aws_access_key_id'] = match.group(2)
        elif match.group(1) == 'AWSSecretKey':
            result['aws_secret_access_key'] = match.group(2)
        else:
            raise ValueError, 'Unrecognized credential <%s>' % match.group(1)
    
    return result

def get_parser(*args, **kwargs):
    """Returns an ArgumentParser preconfigured with global options."""
    parser = argparse.ArgumentParser(*args, **kwargs)
    parser.add_argument('-v', '--verbose', action='store_true', help='Output debugging information')
    credentials_arg = parser.add_argument('-k', '--credentials-file',
        metavar='FILE',
        dest='credentials_file',
        type=argparse.FileType('r'),
        default=os.environ.get('AWS_CREDENTIALS_FILE', '/etc/aws-credentials.txt'),
        help='Path to your AWS credentials file (default: /etc/aws-credentials.txt)'
    )
    
    return parser



import re

from boto.regioninfo import RegionInfo
from boto.ses.connection import SESConnection

from boto_utils.common import parse_aws_credentials_file

def get_ses_connection(args):
    """Given a set of parsed arguments, returns an SESConnection."""
    credentials = parse_aws_credentials_file(args.credentials_file)
    region = RegionInfo(endpoint=args.host)
    connection = SESConnection(debug=(2 if args.verbose else 0), **credentials)
    region.connection = connection
    return connection



from setuptools import setup

setup(
    name='boto_utils',
    version='0.1.7',
    description='Command-line tools based on Boto',
    long_description=open('README.rst', 'r').read(),
    author='Oliver Beattie',
    author_email='oliver@obeattie.com',
    url='https://github.com/obeattie/boto_utils',
    packages=['boto_utils'],
    install_requires=['boto>=2.0'],
    scripts=[
        'boto_utils/ses-send-email',
        'boto_utils/ses-verify-email-address',
        'boto_utils/s3-put',
        'boto_utils/s3-geturl',
        'boto_utils/s3-copy',
    ],
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Programming Language :: Python :: 2.7',
        'Topic :: Utilities',
    ]
)
